@@ -102,9 +102,7 @@ class NeighborInteractionProvider(object):
             if minCount == 0:
                 return True
             if self.__neighborD and minCount and len(self.__neighborD["entries"]) >= minCount:
-                logger.info(
-                    "Target neighbor data for (%d) entries created %r version %r", len(self.__neighborD["entries"]), self.__neighborD["created"], self.__neighborD["version"]
-                )
+                logger.info("Target neighbor data for (%d) entries created %r version %r", len(self.__neighborD["entries"]), self.__neighborD["created"], self.__neighborD["version"])
                 return True
         except Exception:
             pass
@@ -173,13 +171,13 @@ class NeighborInteractionProvider(object):
         return {}
 
     def getAtomCounts(self, entryId):
-        """Return the non-polymer instance occupancy weighted atome counts for the input entry.
+        """Return the non-polymer instance atom counts for the input entry (all reported atoms).
 
         Args:
             entryId (str): entry identifier
 
         Returns:
-            (dict): {asymId: {'FL': count, 'altA': occ*count, 'altB': occ*count, ... }}
+            (dict): {asymId: {'FL': count, 'altA': count, 'altB': count, ... }}
         """
         try:
             return self.__neighborD["entries"][entryId.upper()]["ligandAtomCountD"]
@@ -187,6 +185,21 @@ class NeighborInteractionProvider(object):
             pass
         return {}
 
+    def getHydrogenAtomCounts(self, entryId):
+        """Return the non-polymer instance hydrogen atom counts for the input entry.
+
+        Args:
+            entryId (str): entry identifier
+
+        Returns:
+            (dict): {asymId: {'FL': count, 'altA': count, 'altB': count, ... }}
+        """
+        try:
+            return self.__neighborD["entries"][entryId.upper()]["ligandHydrogenAtomCountD"]
+        except Exception:
+            pass
+        return {}
+
     def hasEntry(self, entryId):
         """Return if the input entry is stored in the cache of non-polymer instance target interactions.
 
